@@ -4,7 +4,7 @@ use File::Path 'mkpath';
 use File::Copy 'copy';
 use Config;
 
-my $VERSION = '1.10';			# Changelog at end
+my $VERSION = '1.10a';			# Changelog at end
 die "Debugging cycle detected"		# set to -1 to allow extra iteration
   if ++$ENV{PERL_DEBUG_MCODE_CYCLE} > 1;
 
@@ -89,7 +89,7 @@ chdir '..' or die "chdir ..: $!"
 
 warn <<EOW;
 
-     >>>	Trying to auto-debug (v=$VERSION): $0 @ARGVi
+     >>>	Checking whether I need to auto-debug (v=$VERSION): $0 @ARGVi
 
 EOW
 # There are 4 cases detected below, with !@ARGV thrown in, one covers 8 types.
@@ -516,3 +516,4 @@ __END__
 	(Temporarily???) Make DLL load-memory-mapping in GDB opt-in via the environment variable AUTO_DBG_LOADMAPS=1.
 	Likewise for dbx (untested) and lldb (untested).
 	Likewise for inspection of candidates for a debugger on a failure of debug script.
+1.10a	Correct the message identifying the auto-debugger since it seems to be always emitted.
\ No newline at end of file
